"""Regular Expression Exercises"""


def count_punctuation():
    """Return count of all punctuation characters in given string."""


def count_numbers():
    """Return the count of all numbers in a given string."""


def get_extension():
    """Return the file extension for a full file path."""


def normalize_jpeg():
    """Return the filename with jpeg extensions normalized."""


def normalize_whitespace():
    """Replace all runs of whitespace with a single space."""


def is_hex_color():
    """Return True iff the string represents an RGB hex color code."""
